## Sizer

A simple Python script for iterating recursively over a directory and returning all of the files sorted by size

### Dependencies

You need Python 3.8+ and to run the following command:

        pip install -r requirements.txt

### Usage

You can use the script as an executable by running:

        python -m sizer

You can also install it with *pipx*. \
For more information on the usege of the script, simply run it with -h. \
\
Alternatively, you can access this as a library by importing from sizer:

        import sizer

